@@ -15,11 +15,11 @@
 #
 ### Parameters ----
 # ; text
-# : The comment text. The content type is "application/x-www-form-urlencoded".
+# : The comment text. The content type is `application/x-www-form-urlencoded`.
 #
 ### Error codes ----
 # ; HTTP status code 400 (Bad Request)
-# : if the text field was not present
+# : If the text field was not present
 # ; HTTP status code 409 (Conflict)
 # : The changeset is not closed
 #
@@ -145,6 +145,141 @@ osm_unsubscribe_changeset_discussion <- function(changeset_id) { # TODO: , forma
 }
 
 
+## Search changeset comments: `GET /api/0.6/changeset_comments` ----
+#
+# Returns changeset comments that match the specified query. If no query is provided, the most recent changeset comments are returned.
+#
+# '''URL:''' <code>https://api.openstreetmap.org/api/0.6/changeset_comments
+# </code>
+### Parameters ----
+# {| class="wikitable"
+# |-
+# !Parameter
+# !Description
+# !Allowed values
+# !Default value
+# |-
+# |<code>display_name</code>
+# | Search for changeset comments created by the given user.
+# |String; User display name
+# |none, optional parameter
+# |-
+# |<code>user</code>
+# |Same as <code>display_name</code>, but search based on user id instead of display name. When both options are provided, <code>display_name</code> takes priority.
+# |Integer; User id
+# |none, optional parameter
+# |-
+# |<code>from</code>
+# | Beginning date range.
+# |Date; Preferably in [https://wikipedia.org/wiki/ISO_8601 ISO 8601] format
+# |none, optional parameter
+# |-
+# |<code>to</code>
+# |End date range. Only works when <code>from</code> is supplied.
+# |Date; Preferably in [https://wikipedia.org/wiki/ISO_8601 ISO 8601] format
+# |none, optional parameter
+# |}
+#
+### Examples ----
+# See the latest changeset comments globally:
+#   https://api.openstreetmap.org/api/0.6/changeset_comments
+# Search for changeset comments by a specific user:
+#   https://api.openstreetmap.org/api/0.6/changeset_comments?display_name=Steve
+# Search for changeset comments between January 1st and January 2nd, 2015:
+#   https://www.openstreetmap.org/api/0.6/changeset_comments?from=2015-01-01&to=2015-01-02
+### Error codes ----
+# ;HTTP status code 400 (Bad Request)
+# :When any of the limits are crossed
+
+#' Search changeset comments
+#'
+#' Returns changeset comments that match the specified query. If no query is provided, the most recent changeset
+#' comments are returned.
+#'
+#' @param user Search for changeset comments created by the user with the given user id (numeric) or display name
+#'   (character).
+#' @param from Beginning date range. See details for the valid formats.
+#' @param to End date range. Only works when `from` is supplied. See details for the valid formats.
+#' @param format Format of the output. Can be `"R"` (default), `"xml"`, or `"json"`.
+#' @param tags_in_columns If `FALSE` (default), the tags of the changesets are saved in a single list column `tags`
+#'   containing a `data.frame` for each changeset with the keys and values. If `TRUE`, add a column for each key.
+#'   Ignored if `format != "R"`.
+#'
+#' @details
+#' The valid formats for `from` and `to` parameters are [POSIXt] values or characters preferably in
+#' [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format.
+#'
+#'
+#' @returns
+#' If `format = "R"`, returns a data frame with one comment per  If `format = "xml"`, returns a
+#' [xml2::xml_document-class]. If `format = "json"`, returns a list with the json structure.
+#'
+#' @family changeset discussion's functions
+#' @export
+#'
+#' @examples
+#' # See the latest changeset comments globally:
+#' osm_search_comment_changeset_discussion()
+#'
+#' # Search for changeset comments by a specific user:
+#' osm_search_comment_changeset_discussion(user = "Steve", format = "json")
+#'
+#' # Search for changeset comments between January 1st and January 2nd, 2015:
+#' osm_search_comment_changeset_discussion(from = "2015-01-01", to = "2015-01-02", format = "xml")
+osm_search_comment_changeset_discussion <- function(user, from, to,
+                                                    format = c("R", "xml", "json"), tags_in_columns = FALSE) {
+  format <- match.arg(format)
+
+  if (missing(user) || is.null(user)) {
+    user <- NULL
+    display_name <- NULL
+  } else {
+    if (is.numeric(user)) {
+      display_name <- NULL
+    } else {
+      display_name <- user
+      user <- NULL
+    }
+  }
+
+  if (missing(from)) {
+    from <- NULL
+  } else if (inherits(from, "POSIXt")) {
+    from <- format(from, "%Y-%m-%dT%H:%M:%SZ")
+  }
+
+  if (missing(to)) {
+    to <- NULL
+  } else if (inherits(to, "POSIXt")) {
+    to <- format(to, "%Y-%m-%dT%H:%M:%SZ")
+  }
+
+  if (format == "json") {
+    ext <- "changeset_comments.json"
+  } else {
+    ext <- "changeset_comments"
+  }
+
+  req <- osmapi_request()
+  req <- httr2::req_method(req, "GET")
+  req <- httr2::req_url_path_append(req, ext)
+  req <- httr2::req_url_query(req, user = user, display_name = display_name, from = from, to = to)
+
+  resp <- httr2::req_perform(req)
+
+  if (format %in% c("R", "xml")) {
+    out <- httr2::resp_body_xml(resp)
+    if (format == "R") {
+      out <- changeset_comments_xml2DF(out)
+    }
+  } else if (format %in% "json") {
+    out <- httr2::resp_body_json(resp)
+  }
+
+  return(out)
+}
+
+
 ## Hide changeset comment: `DELETE /api/0.6/changeset_comments/#id/visibility` ----
 #
 # Also available at `POST /api/0.6/changeset/comment/#comment_id/hide` (deprecated)
